#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 parsers
version:              0.12.10
visibility:           public
id:                   parsers-0.12.10-DGz13yHc7wxB3ssNjoRPte
key:                  parsers-0.12.10-DGz13yHc7wxB3ssNjoRPte
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  53400de2536fe503a194e7f33a30223e
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-8.10.5/site-local/parsers-0.12.10
library-dirs:         /usr/lib/ghc-8.10.5/site-local/parsers-0.12.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/parsers-0.12.10
hs-libraries:         HSparsers-0.12.10-DGz13yHc7wxB3ssNjoRPte
depends:
    base-4.14.2.0 base-orphans-0.8.4-B4zsXTdczgN9mmNUwgnmE3
    binary-0.8.8.0 charset-0.3.8-4iWjhAmMSYyAaq3GWZzCtv
    containers-0.6.4.1 mtl-2.2.2 parsec-3.1.14.0
    scientific-0.3.7.0-Ea1GK6jx8XDEEsfAKxwFym text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

